@@ -606,7 +606,7 @@ async def hyperliquid() -> pl.DataFrame:
     await market_http.async_init()
 
     markets = []
-    res_prep = await market_http.meta()
+    res_prep = await market_http.get_meta()
     df_prep = to_dataframe(res_prep.get("universe", []))
 
     for idx, market in enumerate(df_prep.iter_rows(named=True)):
@@ -627,7 +627,7 @@ async def hyperliquid() -> pl.DataFrame:
             )
         )
 
-    res_spot = await market_http.spot_meta()
+    res_spot = await market_http.get_spot_meta()
     df_tokens = to_dataframe(res_spot.get("tokens", []))
     df_spot = to_dataframe(res_spot.get("universe", []))
 
@@ -785,129 +785,3 @@ async def okx() -> pl.DataFrame:
 
     markets = [market.to_dict() for market in markets]
     return pl.DataFrame(markets)
-
-
-async def zoomex() -> pl.DataFrame:
-    """
-    Fetch market information from ZoomEx exchange.
-
-    Retrieves trading pairs from ZoomEx including linear futures, inverse futures,
-    and spot markets. Standardizes the data into MarketInfo format.
-
-    Returns:
-        Polars DataFrame containing standardized market information from ZoomEx.
-    """
-    from ..zoomex._market_http import MarketHTTP
-
-    market_http = MarketHTTP(preload_product_table=False)
-    await market_http.async_init()
-
-    markets = []
-    linear_data = []
-    cursor = None
-    while True:
-        res_linear = await market_http.get_instruments_info(category="linear", cursor=cursor)
-        linear_data.extend(res_linear["result"]["list"])
-        if res_linear["result"]["nextPageCursor"] == "":
-            break
-        cursor = res_linear["result"]["nextPageCursor"]
-
-    df_linear = to_dataframe(linear_data)
-
-    for market in df_linear.iter_rows(named=True):
-        base = market["baseCoin"]
-        quote = market["quoteCoin"]
-
-        parts = market["symbol"].split("-")
-        if len(parts) >= 2:
-            expiry_str = parts[1]
-            product_symbol = f"{base}-{quote}-{expiry_str}-SWAP"
-        else:
-            product_symbol = f"{base}-{quote}-SWAP"
-
-        if market["contractType"] == "LinearFutures":
-            product_type = "futures"
-        else:
-            product_type = "swap"
-
-        markets.append(
-            MarketInfo(
-                exchange=Common.ZOOMEX,
-                exchange_symbol=market["symbol"],
-                product_symbol=product_symbol,
-                product_type=product_type,
-                exchange_type="linear",
-                base_currency=base,
-                quote_currency=quote,
-                price_precision=market["priceFilter"]["tickSize"],
-                size_precision=market["lotSizeFilter"]["qtyStep"],
-                min_size=market["lotSizeFilter"]["minOrderQty"],
-                min_notional="5",
-            )
-        )
-
-    res_inverse = await market_http.get_instruments_info(category="inverse")
-    df_inverse = (
-        to_dataframe(res_inverse["result"]["list"])
-        if "list" in res_inverse.get("result", {})
-        else pl.DataFrame()
-    )
-    for market in df_inverse.iter_rows(named=True):
-        base = market["baseCoin"]
-        quote = market["quoteCoin"]
-
-        parts = market["symbol"].split("-")
-        if len(parts) >= 2:
-            base, expiry_str = parts[0], parts[1]
-            product_symbol = f"{base}-{quote}-{expiry_str}-SWAP"
-        else:
-            product_symbol = f"{base}-{quote}-SWAP"
-
-        if market["contractType"] == "LinearFutures":
-            product_type = "futures"
-        else:
-            product_type = "swap"
-
-        markets.append(
-            MarketInfo(
-                exchange=Common.ZOOMEX,
-                exchange_symbol=market["symbol"],
-                product_symbol=product_symbol,
-                product_type=product_type,
-                exchange_type="inverse",
-                base_currency=base,
-                quote_currency=quote,
-                price_precision=market["priceFilter"]["tickSize"],
-                size_precision=market["lotSizeFilter"]["qtyStep"],
-                min_size=market["lotSizeFilter"]["minOrderQty"],
-            )
-        )
-
-    res_spot = await market_http.get_instruments_info(category="spot")
-    df_spot = (
-        to_dataframe(res_spot["result"]["list"])
-        if "list" in res_spot.get("result", {})
-        else pl.DataFrame()
-    )
-    for market in df_spot.iter_rows(named=True):
-        base = market["baseCoin"]
-        quote = market["quoteCoin"]
-        product_symbol = f"{base}-{quote}-SPOT"
-
-        markets.append(
-            MarketInfo(
-                exchange=Common.ZOOMEX,
-                exchange_symbol=market["symbol"],
-                product_symbol=product_symbol,
-                product_type="spot",
-                exchange_type="spot",
-                base_currency=base,
-                quote_currency=quote,
-                price_precision=market["priceFilter"]["tickSize"],
-                size_precision=market["lotSizeFilter"]["basePrecision"],
-                min_size=market["lotSizeFilter"]["minOrderQty"],
-                min_notional=market["lotSizeFilter"].get("minNotionalValue", "0"),
-            )
-        )
-    markets = [market.to_dict() for market in markets]
-    return pl.DataFrame(markets)
