@@ -499,6 +499,72 @@ def gateio() -> pl.DataFrame:
     return pl.DataFrame(markets)
 
 
+def hyperliquid() -> pl.DataFrame:
+    """
+    Fetch market information from Hyperliquid exchange.
+
+    Retrieves trading pairs from Hyperliquid including perpetual swaps and spot markets.
+    Standardizes the data into MarketInfo format.
+
+    Returns:
+        Polars DataFrame containing standardized market information from Hyperliquid.
+    """
+    from ..hyperliquid._market_http import MarketHTTP
+
+    market_http = MarketHTTP(preload_product_table=False)
+
+    markets = []
+    res_prep = market_http.get_meta()
+    df_prep = to_dataframe(res_prep.get("universe", []))
+
+    for idx, market in enumerate(df_prep.iter_rows(named=True)):
+        coin = market["name"]
+        tick = str(reverse_decimal_places(market["szDecimals"]))
+        markets.append(
+            MarketInfo(
+                exchange=Common.HYPERLIQUID,
+                exchange_symbol=f'["{coin}", {idx}]',
+                product_symbol=f"{coin}-USD-SWAP",
+                product_type="swap",
+                exchange_type="perpetual",
+                base_currency=coin,
+                quote_currency="USD",
+                price_precision=tick,
+                size_precision=tick,
+                min_size=tick,
+            )
+        )
+
+    res_spot = market_http.get_spot_meta()
+    df_tokens = to_dataframe(res_spot.get("tokens", []))
+    df_spot = to_dataframe(res_spot.get("universe", []))
+
+    for idx, market in enumerate(df_spot.iter_rows(named=True)):
+        # exchange_symbol = market["name"]
+        base_i, quote_i = market["tokens"]
+
+        base = df_tokens["name"][base_i]  # e.g. "PURR"
+        quote = df_tokens["name"][quote_i]  # e.g. "USDC"
+        tick = str(reverse_decimal_places(df_tokens["szDecimals"][base_i]))
+
+        markets.append(
+            MarketInfo(
+                exchange=Common.HYPERLIQUID,
+                exchange_symbol='["{}", {}]'.format(market["name"], 10000 + idx),
+                product_symbol=f"{base}-{quote}-SPOT",
+                product_type="spot",
+                exchange_type="spot",
+                base_currency=base,
+                quote_currency=quote,
+                price_precision=tick,
+                size_precision=tick,
+                min_size=tick,
+            )
+        )
+    markets = [market.to_dict() for market in markets]
+    return pl.DataFrame(markets)
+
+
 def okx() -> pl.DataFrame:
     """
     Fetch product information from OKX exchange.
